@@ -1,5 +1,5 @@
 #!/usr/bin/perl
-# $Id: Makefile-5005.pm 2357 2008-06-20 17:41:54Z rcaputo $
+# rocco // vim: ts=2 sw=2 expandtab
 
 use strict;
 
@@ -22,6 +22,10 @@ use PoeBuildInfo qw(
 open(TOUCH, ">>CHANGES") and close TOUCH;
 open(TOUCH, ">>META.yml") and close TOUCH;
 
+### Touch gen-tests.perl so it always triggers.
+
+utime(time(), time(), "mylib/gen-tests.perl");
+
 ### Some advisory dependency testing.
 
 sub check_for_modules {
@@ -62,8 +66,6 @@ check_for_modules(
   "optional",
   "Compress::Zlib"  => 1.33,
   "Curses"          => 1.08,
-  "Event"           => 1.00,
-  "Gtk"             => 0.7009,
   "IO::Poll"        => 0.01,
   "IO::Pty"         => 1.02,
   "LWP"             => 5.79,
@@ -72,14 +74,9 @@ check_for_modules(
   "Term::Cap"       => 1.09,
   "Term::ReadKey"   => 2.21,
   RECOMMENDED_TIME_HIRES,
-  "Tk"              => 800.027,
   "URI"             => 1.30,
 );
 
-### Generate dynamic test files.
-
-system($^X, "mylib/gen-tests.perl") and die "couldn't generate tests: $!";
-
 ### Generate Makefile.PL.
 
 sub MY::postamble {
@@ -115,7 +112,7 @@ WriteMakefile(
     COMPRESS => 'gzip -9f',
     SUFFIX   => 'gz',
     PREOP    => (
-      './mylib/svn-log.perl | ' .
+      'git-log.pl | ' .
       '/usr/bin/tee ./$(DISTNAME)-$(VERSION)/CHANGES > ./CHANGES; ' .
       "$^X mylib/gen-meta.perl; " .
       '/bin/cp -f ./META.yml ./$(DISTNAME)-$(VERSION)/META.yml'
@@ -130,8 +127,12 @@ WriteMakefile(
     TESTS => TEST_FILES,
   },
 
+  # Not executed on "make test".
+  PL_FILES       => {
+    'mylib/gen-tests.perl' => [ 'lib/POE.pm' ],
+  },
+
   # More for META.yml than anything.
-  PL_FILES       => { },
   NO_META        => 1,
   PREREQ_PM      => { CORE_REQUIREMENTS },
 );
